package com.huimv.eartag.service;

import com.huimv.eartag.vo.Result;

import java.text.ParseException;

public interface IEartagManageService {
    //
    Result getEartagRegisterByEarmark(String earmark) throws ParseException;

    //根据耳标号读取今天所有流水
    Result listEartagFlowByEarmarkAndToday(String earmark) throws ParseException;

    Result listEartagFlowByDeviceCodeAndEarmarkAndToday(String earmark, String deviceCode) throws ParseException;

    //显示耳标在线统计
    Result listEartagOnlineCountByEarmarkAndDate(String earmark, Integer pastDays, Integer showMode) throws ParseException;

    //显示耳标在线统计
    Result listEartagOnlineStatusByEarmarkAndDate(String earmark, Integer pastDays) throws ParseException;

    //带分页查询耳标流水
    Result listEartagFlowByEarmarkAndTodayInPager(String earmark, Integer pageNo, Integer pageSize, String createDate, String deviceCode) throws ParseException;

    //带分页查询耳标流水
    Result listEartagFlowByDeviceCodeAndEarmarkAndTodayInPager(String earmark, String deviceCode, String createDate, Integer pageNo, Integer pageSize) throws ParseException;

    //带分页查询耳标流水
    Result listEartagFlowByDeviceCodeAndEarmarkAndDateInPager(String earmark, String deviceCode, String addDate, Integer pageNo, Integer pageSize) throws ParseException;

    //前N天的耳标在线状态
    Result listEartagOnlineAllStatus(String farmId, Integer days) throws ParseException;

    //展示在线耳标列表
    Result listOnlineEartagCount(String farmId, String addDate, Integer pageNo, Integer pageSize, Integer showMode) throws ParseException;

    //获取该耳边前N天历史记录
//    Result getEartagOnlineCountByEarmark(String earmark, Integer days) throws ParseException;

    //通过耳标号和日期获取耳标关联设备信息
    Result listEartagDeviceByEarmarkAndAddDate(String earmark, String addDate);

    //分页展示所有耳标注册列表
    Result listAllEartagRegister(String farmId, String earmark, Integer activeStatus, Integer liveStatus, Integer registerType, String startDate, String endDate, Integer pageNo, Integer pageSize) throws ParseException;

    //分页展示所有耳标流水列表
    Result listAllEartagFlow(String farmId, String createDate, String deviceCode, String earmark, Integer pageNo, Integer pageSize) throws ParseException;

    //
    Result listManyEartagOnlineStatus(String farmId, Integer days) throws ParseException;
}
